# Primeiro_Pacote

O pacote diz olá

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install package_name
```

## Usage

```python
from package_name import file1_name
file1_name.ola()
```

## Author
Rayron Soares C

## License
[MIT](https://choosealicense.com/licenses/mit/)